@@ -60,6 +60,7 @@ report_note = function(xx) {
 #' @param plot_unmutated Plot base composition using only unmutated sequences (V-chains only)
 #' @param all_inferred Treat all alleles as novel
 #' @param format The format for the plot file ('pdf', 'html' or 'none')
+#' @param custom_file_prefix custom prefix to use for output files. If not specified, the prefix is taken from the input file name
 #' @return None
 #' @export
 #' @examples
@@ -77,7 +78,7 @@ report_note = function(xx) {
 #' outfile = file.path(tempdir(), 'ogrdbstats_example_repertoire_ogrdb_report.csv')
 #' file.remove(repfile)
 #' file.remove(outfile)
-generate_ogrdb_report = function(ref_filename, inferred_filename, species, filename, chain, hap_gene, segment, chain_type, plot_unmutated, all_inferred=FALSE, format='pdf') {
+generate_ogrdb_report = function(ref_filename, inferred_filename, species, filename, chain, hap_gene, segment, chain_type, plot_unmutated, all_inferred=FALSE, format='pdf', custom_file_prefix='') {
   if (format == 'none') {
     return(invisible())
   }
@@ -108,7 +109,13 @@ generate_ogrdb_report = function(ref_filename, inferred_filename, species, filen
   rd = read_input_files(ref_filename, inferred_filename, species, filename, chain, hap_gene, segment, chain_type, all_inferred)
   file_base = basename(filename)
   file_splits = strsplit(file_base, '.', fixed=TRUE)[[1]]
-  file_prefix = paste(file_splits[1:length(file_splits)-1], sep='.', collapse='.')
+
+  if (custom_file_prefix != '') {
+    file_prefix = custom_file_prefix
+  } else {
+    file_prefix = paste(file_splits[1:length(file_splits)-1], sep='.', collapse='.')
+  }
+
   file_loc = dirname(filename)
 
   write_genotype_file(file.path(file_loc, paste0(file_prefix, '_ogrdb_report.csv')), segment, chain_type, rd$genotype)
@@ -568,7 +575,18 @@ calc_haplo_details = function(segment, input_sequences) {
     sa = rename(sa, A_CALL=V_CALL)
   }
 
-  sa$a_gene = sapply(sa$A_CALL, function(x) {strsplit(x, '*', fixed=TRUE)[[1]][[1]]})
+  sa$a_gene = sapply(sa$A_CALL, function(x) {
+      if (grepl('*', x, fixed=TRUE)) {
+        strsplit(x, '*', fixed=TRUE)[[1]][[1]]
+      } else {
+        'X'
+      }
+    })
+
+  if (nrow(sa) == 0) {
+    return(list())
+  }
+
   sa$a_allele = sapply(sa$A_CALL, function(x) {
       if (grepl('*', x, fixed=TRUE)) {
         strsplit(x, '*', fixed=TRUE)[[1]][[2]]
